# gabes_firstpackage

gabes_firstpackage is my first attempt at creating a package. I chose to use my first Multilayer Perceptron code for this package, whose objective was to help me learn OOP and to improve my understading of neural networks, the backpropagation algorithm and its equations. 

This also my first time using a repository (and therefore GitHub). Long story short: this project is not supposed to be anything fancy, it's just a personal project so I can hone my Python skills an refresh some knowledge.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install gabes_firstpackage.

```bash
pip install gabes-firstpackage
```

## Sucess!

As of 30/12/2023 20:49 UTC-3 I've sucessfully distributed a working version of gabes_firstpackage. I used a local host on Google Colab to try it out on some small datasets I had. You may find my results on the following links:

https://colab.research.google.com/drive/1NOMsq0moVhtMWS-GGYQInNpougVmDplP?usp=sharing

https://colab.research.google.com/drive/1qCntDWHbeOd_MaeNS36MUYEs4SXMZhLo?usp=sharing

Like I've previously said, this was just a personal project so that I could improve some of my skills, so I took a simplistic approach for most things. 

I don't intend to make any changes to this project for a long while, but I do hope some other student stumbles upon it and makes good use of it.
